Index: main/plugin-link-directory/src/org/ametys/plugins/linkdirectory/DirectoryHelper.java
===================================================================
--- main/plugin-link-directory/src/org/ametys/plugins/linkdirectory/DirectoryHelper.java	(revision 28682)
+++ main/plugin-link-directory/src/org/ametys/plugins/linkdirectory/DirectoryHelper.java	(working copy)
@@ -1,5 +1,5 @@
 /*
- *  Copyright 2012 Anyware Services
+ *  Copyright 2014 Anyware Services
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -62,10 +62,10 @@
     }
     
     /**
-     * Get the word definitions storage node.
+     * Get the links root node.
      * @param site the site
      * @param language the language.
-     * @return the word definitions storage node.
+     * @return the links root node.
      * @throws AmetysRepositoryException if a repository error occurs.
      */
     public static ModifiableTraversableAmetysObject getLinksNode(Site site, String language) throws AmetysRepositoryException
@@ -83,15 +83,15 @@
         }
         catch (AmetysRepositoryException e)
         {
-            throw new AmetysRepositoryException("Error getting the word definitions node for site " + site.getName() + " and language " + language, e);
+            throw new AmetysRepositoryException("Error getting the link directory root node for site " + site.getName() + " and language " + language, e);
         }
     }
 
     /**
-     * Get the word definitions storage node.
+     * Get the themes storage node.
      * @param site the site
      * @param language the language.
-     * @return the word definitions storage node.
+     * @return the themes storage node.
      * @throws AmetysRepositoryException if a repository error occurs.
      */
     public static ModifiableTraversableAmetysObject getThemesNode(Site site, String language) throws AmetysRepositoryException
@@ -114,9 +114,9 @@
     }
     
     /**
-     * Get the word definitions storage node.
+     * Get the plugin node path
      * @param siteName the site name.
-     * @return the word definitions storage node.
+     * @return the plugin node path.
      */
     public static String getPluginNodePath(String siteName)
     {
@@ -124,10 +124,10 @@
     }
     
     /**
-     * Get the word definitions storage node.
+     * Get the links root node path
      * @param siteName the site name.
      * @param language the language.
      * @return the word definitions storage node.
      */
     public static String getLinksNodePath(String siteName, String language)
     {
@@ -135,10 +135,10 @@
     }
     
     /**
-     * Get the word definitions storage node.
+     * Get the themes node path
      * @param siteName the site name.
-     * @param language the language.
-     * @return the word definitions storage node.
+     * @param language the language
+     * @return the themes node path.
      */
     public static String getThemesNodePath(String siteName, String language)
     {
@@ -146,7 +146,7 @@
     }
     
     /**
-     * Get the word definitions storage node.
+     * Get the link query corresponding to the expression passed as a parameter
      * @param siteName the site name.
      * @param language the language.
      * @param expression 
@@ -158,7 +158,7 @@
     }
     
     /**
-     * Get the word definitions storage node.
+     * Get the query verifying the existence of an url
      * @param siteName the site name.
      * @param language the language.
      * @param url the url to test. 
@@ -171,10 +171,10 @@
     }
     
     /**
-     * Get the word definitions storage node.
+     * Get the query verifying the existence of a theme
      * @param siteName the site name.
      * @param language the language.
-     * @param label the label to test. 
+     * @param label the label of the theme to test. 
      * @return the word definitions storage node.
      */
     public static String getThemeExistsQuery(String siteName, String language, String label)
@@ -124,10 +124,10 @@
      * @param siteName the site name.
-     * @param language the language.
-     * @return the word definitions storage node.
+     * @param language the language
+     * @return the links root node path.
      */
     public static String getLinksNodePath(String siteName, String language)
